@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-import sqlite3
-
-from cator.common import dict_factory
-
-from ..base import Database
-from ..sql import SqlUtil
-from .table import SqliteTable
 from enum import Enum
+from sqlite3 import connect, paramstyle
+
+from cator.base.dbapi import ParamStyleConvert
+from cator.logger import logger
+
+from .table import SqliteTable
+from ..base import Database
 
 
 # doc： https://www.sqlite.org/lang_transaction.html#immediate
@@ -22,24 +22,13 @@ class SqliteDatabase(Database):
     doc: https://docs.python.org/zh-cn/3.7/library/sqlite3.html
     """
 
-    def cursor(self):
-        return self.connection.cursor()
-
-    @property
-    def isolation_level(self):
-        return self._connection.isolation_level
-
-    @isolation_level.setter
-    def isolation_level(self, value: bool):
-        self._connection.isolation_level = value
-
     def connect(self):
-        self._connection = sqlite3.connect(**self.config)
-        self._connection.row_factory = dict_factory
+        self._connection = connect(**self.config)
+        logger.debug("Database open")
 
     def before_execute(self, sql, params=None):
-        _sql = SqlUtil.prepare_sqlite_sql(sql)
-        return super().before_execute(_sql, params)
+        sql = ParamStyleConvert.convert(paramstyle=paramstyle, sql=sql)
+        return super().before_execute(sql, params)
 
     @property
     def tables(self):
